;;;; This file is part of cl-ncurses, an ncurses interface for Common Lisp,
;;;; Copyright (c) 2004 Marcelo Ramos <mramos@montevideo.com.uy>
;;;;
;;;; Permission is hereby granted, free of charge, to any person obtaining
;;;; a copy of this software and associated documentation files (the
;;;; "Software"), to deal in the Software without restriction, including
;;;; without limitation the rights to use, copy, modify, merge, publish,
;;;; distribute, sublicense, and/or sell copies of the Software, and to
;;;; permit persons to whom the Software is furnished to do so, subject to
;;;; the following conditions:
;;;;
;;;; The above copyright notice and this permission notice shall be included
;;;; in all copies or substantial portions of the Software.
;;;;
;;;; THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
;;;; EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
;;;; MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
;;;; IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
;;;; CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
;;;; TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
;;;; SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

;;;;;;;;;;;
;; GETYX ;;
;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Routines: getyx, getparyx, getbegyx, getmaxyx                              ;;
;; Purpose:  Get curses cursor and window coordinates.                        ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :cl-ncurses)

; C Prototype: void getyx(WINDOW *win, int y, int x);
; C Prototype: void getparyx(WINDOW *win, int y, int x);
; C Prototype: void getbegyx(WINDOW *win, int y, int x);
; C Prototype: void getmaxyx(WINDOW *win, int y, int x);

(def-struct result
	    (x :int) 
	    (y :int))

(defmacro getyx (win y x)
  `(let ((r (allocate-foreign-object 'result)))
     (wrap-getyx ,win r)
     (setf x (get-slot-value r 'result 'x))
     (setf y (get-slot-value r 'result 'y))
     (free-foreign-object r)))

(defmacro getparyx (win y x)
  `(let ((r (allocate-foreign-object 'result)))
     (wrap-getyx ,win r)
     (setf x (get-slot-value r 'result 'x))
     (setf y (get-slot-value r 'result 'y))
     (free-foreign-object r)))

(defmacro getbegyx (win y x)
  `(let ((r (allocate-foreign-object 'result)))
     (wrap-getyx ,win r)
     (setf x (get-slot-value r 'result 'x))
     (setf y (get-slot-value r 'result 'y))
     (free-foreign-object r)))

(defmacro getmaxyx (win y x)
  `(let ((r (allocate-foreign-object 'result)))
     (wrap-getyx ,win r)
     (setf x (get-slot-value r 'result 'x))
     (setf y (get-slot-value r 'result 'y))
     (free-foreign-object r)))

